@@ -12,8 +12,8 @@ import (
 	"github.com/docker/docker/api/types/container"
 	mounttypes "github.com/docker/docker/api/types/mount"
 	"github.com/docker/docker/api/types/swarm"
-	"gotest.tools/assert"
-	is "gotest.tools/assert/cmp"
+	"gotest.tools/v3/assert"
+	is "gotest.tools/v3/assert/cmp"
 )
 
 func TestUpdateServiceArgs(t *testing.T) {
@@ -28,7 +28,7 @@ func TestUpdateServiceArgs(t *testing.T) {
 	cspec := spec.TaskTemplate.ContainerSpec
 	cspec.Args = []string{"old", "args"}
 
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, is.DeepEqual([]string{"the", "new args"}, cspec.Args))
 }
 
@@ -358,15 +358,19 @@ func TestUpdateHosts(t *testing.T) {
 	flags := newUpdateCommand(nil).Flags()
 	flags.Set("host-add", "example.net:2.2.2.2")
 	flags.Set("host-add", "ipv6.net:2001:db8:abc8::1")
+	// adding the special "host-gateway" target should work
+	flags.Set("host-add", "host.docker.internal:host-gateway")
 	// remove with ipv6 should work
 	flags.Set("host-rm", "example.net:2001:db8:abc8::1")
 	// just hostname should work as well
 	flags.Set("host-rm", "example.net")
+	// removing the special "host-gateway" target should work
+	flags.Set("host-rm", "gateway.docker.internal:host-gateway")
 	// bad format error
 	assert.ErrorContains(t, flags.Set("host-add", "$example.com$"), `bad format for add-host: "$example.com$"`)
 
-	hosts := []string{"1.2.3.4 example.com", "4.3.2.1 example.org", "2001:db8:abc8::1 example.net"}
-	expected := []string{"1.2.3.4 example.com", "4.3.2.1 example.org", "2.2.2.2 example.net", "2001:db8:abc8::1 ipv6.net"}
+	hosts := []string{"1.2.3.4 example.com", "4.3.2.1 example.org", "2001:db8:abc8::1 example.net", "gateway.docker.internal:host-gateway"}
+	expected := []string{"1.2.3.4 example.com", "4.3.2.1 example.org", "2.2.2.2 example.net", "2001:db8:abc8::1 ipv6.net", "host-gateway host.docker.internal"}
 
 	err := updateHosts(flags, &hosts)
 	assert.NilError(t, err)
@@ -532,18 +536,18 @@ func TestUpdateReadOnly(t *testing.T) {
 	// Update with --read-only=true, changed to true
 	flags := newUpdateCommand(nil).Flags()
 	flags.Set("read-only", "true")
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, cspec.ReadOnly)
 
 	// Update without --read-only, no change
 	flags = newUpdateCommand(nil).Flags()
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, cspec.ReadOnly)
 
 	// Update with --read-only=false, changed to false
 	flags = newUpdateCommand(nil).Flags()
 	flags.Set("read-only", "false")
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, !cspec.ReadOnly)
 }
 
@@ -558,18 +562,18 @@ func TestUpdateInit(t *testing.T) {
 	// Update with --init=true
 	flags := newUpdateCommand(nil).Flags()
 	flags.Set("init", "true")
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, is.Equal(true, *cspec.Init))
 
 	// Update without --init, no change
 	flags = newUpdateCommand(nil).Flags()
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, is.Equal(true, *cspec.Init))
 
 	// Update with --init=false
 	flags = newUpdateCommand(nil).Flags()
 	flags.Set("init", "false")
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, is.Equal(false, *cspec.Init))
 }
 
@@ -584,18 +588,18 @@ func TestUpdateStopSignal(t *testing.T) {
 	// Update with --stop-signal=SIGUSR1
 	flags := newUpdateCommand(nil).Flags()
 	flags.Set("stop-signal", "SIGUSR1")
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, is.Equal("SIGUSR1", cspec.StopSignal))
 
 	// Update without --stop-signal, no change
 	flags = newUpdateCommand(nil).Flags()
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, is.Equal("SIGUSR1", cspec.StopSignal))
 
 	// Update with --stop-signal=SIGWINCH
 	flags = newUpdateCommand(nil).Flags()
 	flags.Set("stop-signal", "SIGWINCH")
-	updateService(nil, nil, flags, spec)
+	updateService(context.TODO(), nil, flags, spec)
 	assert.Check(t, is.Equal("SIGWINCH", cspec.StopSignal))
 }
 
